==> aws-java-sdk-cloudhsm-1.9.16-sources.jar: com/amazonaws/services/cloudhsm/model/ListAvailableZonesRequest.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudhsm.model;

import java.io.Serializable;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.cloudhsm.AWSCloudHSM#listAvailableZones(ListAvailableZonesRequest) ListAvailableZones operation}.
 * <p>
 * Lists the Availability Zones that have available AWS CloudHSM
 * capacity.
 * </p>
 *
 * @see com.amazonaws.services.cloudhsm.AWSCloudHSM#listAvailableZones(ListAvailableZonesRequest)
 */
public class ListAvailableZonesRequest extends AmazonWebServiceRequest implements Serializable {

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ListAvailableZonesRequest == false) return false;
        ListAvailableZonesRequest other = (ListAvailableZonesRequest)obj;
        
        return true;
    }
    
}

==> aws-java-sdk-cloudhsm-1.10.14-sources.jar: com/amazonaws/services/cloudhsm/model/ListAvailableZonesRequest.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudhsm.model;

import java.io.Serializable;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * Container for the parameters to the {@link com.amazonaws.services.cloudhsm.AWSCloudHSM#listAvailableZones(ListAvailableZonesRequest) ListAvailableZones operation}.
 * <p>
 * Lists the Availability Zones that have available AWS CloudHSM
 * capacity.
 * </p>
 *
 * @see com.amazonaws.services.cloudhsm.AWSCloudHSM#listAvailableZones(ListAvailableZonesRequest)
 */
public class ListAvailableZonesRequest extends AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ListAvailableZonesRequest == false) return false;
        ListAvailableZonesRequest other = (ListAvailableZonesRequest)obj;
        
        return true;
    }
    
    @Override
    public ListAvailableZonesRequest clone() {
        
            return (ListAvailableZonesRequest) super.clone();
    }

}
